gchecky.model.tax_tables_t

Package gchecky :: Module model :: Class tax_tables_t |
[hide private]
[frames] | no frames]

# Class tax_tables_t

source code

    object --+
             |
     gxml.Node --+
                 |
                tax_tables_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| merchant_calculated = `gxml.Boolean('@merchant-calculated', def`...``
| default = `Node:PATH(default-tax-table):REQ:{ default_tax_table`...``
| alternates = `List:PATH(alternate-tax-tables):OP`...``
| _fields = ``{``'``alternates``'``:` List:PATH(alternate-tax-tables):OP`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### merchant_calculated Value:
      gxml.Boolean('@merchant-calculated', default= False)

  ### default Value:
      Node:PATH(default-tax-table):REQ:{ default_tax_table_t }

  ### alternates Value:
      List:PATH(alternate-tax-tables):OPT:[
          Node:PATH(alternate-tax-table):REQ:{ alternate_tax_table_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'alternates': List:PATH(alternate-tax-tables):OPT:[
          Node:PATH(alternate-tax-table):REQ:{ alternate_tax_table_t }
      ],
       'default': Node:PATH(default-tax-table):REQ:{ default_tax_table_t },
       'merchant_calculated': ??}